## START: Set by rpmautospec
## (rpmautospec version 0.2.5)
%define autorelease(e:s:pb:) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{?dist}
## END: Set by rpmautospec

%if 0%{?fedora} >= 36
# Folly is compiled with Clang
%bcond_without toolchain_clang
%else
%bcond_with toolchain_clang
%endif

%if %{with toolchain_clang}
%global toolchain clang
%endif

%bcond_without check

# use this to re-test running all tests
%bcond_with all_tests

%ifarch aarch64
# needed until these are merged and released
# https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/175
# https://src.fedoraproject.org/rpms/redhat-rpm-config/pull-request/176
%global optflags %(echo %{optflags} | sed 's/ -mbranch-protection=standard//')
%endif

Name:           fbzmq
Version:        2022.03.14.00
Release:        %autorelease
Summary:        Framework for writing services in C++ while leveraging libzmq

License:        MIT
URL:            https://github.com/facebook/fbzmq
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Patch:          %{name}-fix_unused_lambda_capture.patch

# Folly is known not to work on big-endian CPUs
# https://bugzilla.redhat.com/show_bug.cgi?id=1910202
ExcludeArch:    s390x
%if 0%{?fedora} >= 36
# fmt code breaks: https://bugzilla.redhat.com/show_bug.cgi?id=2061022
ExcludeArch:    ppc64le
%endif

BuildRequires:  cmake
%if %{with toolchain_clang}
BuildRequires:  clang
%else
BuildRequires:  gcc-c++
%endif
# Library dependencies
BuildRequires:  fbthrift-devel
BuildRequires:  fizz-devel
BuildRequires:  folly-devel
BuildRequires:  wangle-devel
BuildRequires:  zeromq-devel
# Test dependencies
%if %{with check}
BuildRequires:  gmock-devel
BuildRequires:  gtest-devel
%endif

%global _description %{expand:
fbzmq provides a framework for writing services in C++ while leveraging the
awesomeness of libzmq (message passing semantics). At a high level it provides

- Lightweight C++ wrapper over libzmq which leverages newer C++ constructs and
  stricter type checking. Most notably it provides the ability to send/receive
  thrift objects as messages over wire without worrying about wire
  encoding/decoding protocols.
- Powerful Async Framework with EventLoop, Timeouts, SignalHandler and more to
  enable developers to write asynchronous applications efficiently.
- Suite of monitoring tools that make it easy to add logging and counters to
  your service.}

%description %{_description}


%package        devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       cmake-filesystem
Obsoletes:      %{name}-static < 2022.02.21.00-1

%description    devel %{_description}

The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%autosetup -p1


%build
%cmake \
  -DBUILD_SHARED_LIBS=ON \
%if %{with check}
  -DBUILD_TESTS=ON \
%else
  -DBUILD_TESTS=OFF \
%endif
  -DCMAKE_INSTALL_DIR=%{_libdir}/cmake/%{name} \
  -DPACKAGE_VERSION=%{version} \
  -DSO_VERSION=%{version}
%cmake_build


%install
%cmake_install


%if %{with check}
%check
# we can't use the ctest macro directly as the tests are in a subdirectory
pushd "%{__cmake_builddir}/fbzmq"
EXCLUDED_TESTS=
%if %{without all_tests}
EXCLUDED_TESTS+='-E SystemMetricsTest'
%endif
%__ctest --output-on-failure --force-new-ctest-process %{?_smp_mflags} ${EXCLUDED_TESTS}
popd
%endif


%files
%license LICENSE
%doc README.md
%{_libdir}/*.so.%{version}

%files devel
%license LICENSE-examples
%doc CODE_OF_CONDUCT.md CONTRIBUTING.md fbzmq/examples
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/cmake/%{name}


%changelog
* Thu Mar 17 2022 Michel Alexandre Salim <salimma@fedoraproject.org> 2022.03.14.00-1
- Update to 2022.03.14.00

* Thu Mar 17 2022 Michel Alexandre Salim <salimma@fedoraproject.org> 2022.03.07.00-1
- Update to 2022.03.07.00 (resolves: rhbz#2035843)

* Thu Mar 17 2022 Michel Alexandre Salim <salimma@fedoraproject.org> 2022.02.28.00-1
- Update to 2022.02.28.00

* Mon Feb 28 2022 Michel Alexandre Salim <salimma@fedoraproject.org> 2022.02.21.00-1
- Update to 2022.02.21.00; drop static build

* Mon Feb 28 2022 Fedora Release Engineering <releng@fedoraproject.org> 2021.12.20.00-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Dec 23 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.12.20.00-1
- Update to 2021.12.20.00

* Fri Nov 12 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.11.08.00-1
- Update to 2021.11.08.00

* Fri Aug 06 2021 Jonathan Wakely <jwakely@redhat.com> - 2021.07.22.00-2
- Rebuilt for Boost 1.76

* Sun Aug  1 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.07.22.00-1
- Update to 2021.07.22.00

* Wed Jul 21 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2021.06.28.00-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Tue Jul 13 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.06.28.00-1
- Update to 2021.06.28.00

* Mon May 10 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.05.10.00-1
- Update to 2021.05.10.00

* Mon Apr 26 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.04.26.00-1
- Update to 2021.04.26.00

* Fri Apr 16 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.04.12.00-1
- Update to 2021.04.12.00

* Mon Mar 29 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.03.29.00-1
- Update to 2021.03.29.00

* Wed Mar 24 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.03.22.00-1
- Update to 2021.03.22.00

* Mon Mar 15 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.03.15.00-1
- Update to 2021.03.15.00

* Wed Feb 03 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.02.01.00-1
- Update to 2021.02.01.00

* Tue Jan 26 17:50:58 PST 2021 Michel Alexandre Salim <salimma@fedoraproject.org> - 2021.01.25.00-1
- Update to 2021.01.25.00

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2020.12.28.00-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Fri Jan 22 2021 Jonathan Wakely <jwakely@redhat.com> - 2020.12.28.00-2
- Rebuilt for Boost 1.75

* Tue Dec 29 12:16:18 PST 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.12.28.00-1
- Update to 2020.12.28.00

* Tue Dec 22 16:59:00 PST 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.12.21.00-1
- Update to 2020.12.21.00

* Mon Nov 30 10:42:58 PST 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.11.30.00-1
- Update to 2020.11.30.00

* Mon Nov 23 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.11.23.00-1
- Update to 2020.11.23.00

* Mon Nov 16 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.11.16.00-1
- Update to 2020.11.16.00

* Fri Nov 13 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.11.09.00-2
- Fix for type mismatch on 32-bit architectures
- Fix ctest invocation
- Disable failing timeout test

* Wed Nov 11 2020 Michel Alexandre Salim <salimma@fedoraproject.org> - 2020.11.09.00-1
- Initial package

